import { ClientAdapter, Request, Response, ServerAdapter, ServerConfiguration, Tokens, UsernamePasswordCredentials } from '../auth-toolbox';
export interface LoginResponse {
    access_token: string;
    expires_in: number;
    refresh_expires_in: number;
    refresh_token: string;
}
export interface OpenidConfiguration {
    token_endpoint: string;
    userinfo_endpoint: string;
    end_session_endpoint: string;
}
/**
 * Provides a {@link ServerConfiguration} through [OpenID discovery](https://openid.net/specs/openid-connect-discovery-1_0.html).
 *
 * It requests `{issuerUrl}/.well-known/openid-configuration` to retrieve login, renew and logout
 * endpoints.
 *
 * It should be given to {@link Auth} constructor.
 *
 * @param client client adapter to request discovery endpoint with.
 * @param issuerUrl url of the authentication realm (without `/.well-known/openid-configuration`).
 */
export declare function openidConnectDiscovery<R>(client: ClientAdapter<R>, issuerUrl: string): Promise<ServerConfiguration>;
/**
 * Implements OpenID Connect "Resource Owner Password Credentials Grant", it should be given to
 * {@link Auth} constructor.
 */
export declare class OpenidConnectAdapter implements ServerAdapter {
    asLoginRequest(serverConfiguration: ServerConfiguration, credentials: UsernamePasswordCredentials): Request;
    asLogoutRequest(serverConfiguration: ServerConfiguration, tokens: Tokens | undefined): Request | null;
    asRenewRequest(serverConfiguration: ServerConfiguration, tokens: Tokens | undefined): Request | null;
    shouldPersistCredentials(serverConfiguration: ServerConfiguration): boolean;
    getResponseTokens(response: Response): Tokens;
    configureRequest(request: Request, tokens: Tokens): void;
    shouldRenew(request: Request, response: Response): boolean;
    isExpired(request: Request, response: Response): boolean;
}
